==> thirdparty-service-biz-1.0.53-sources.jar: cn/com/duiba/orderstatus/OrderStatusPushHttp.java <==
package cn.com.duiba.orderstatus;

import cn.com.duiba.biz.credits.strategy.ApiStrategyRouter;
import cn.com.duiba.config.OrderStatusPushConfig;
import cn.com.duiba.credits.sdk.SignTool;
import cn.com.duiba.dao.AppDAO;
import cn.com.duiba.dao.HttpMessageDAO;
import cn.com.duiba.domain.AppDO;
import cn.com.duiba.domain.HttpMessageDO;
import cn.com.duiba.notifycenter.service.NotifyHttpClientPool;
import cn.com.duiba.service.CustomService;
import cn.com.duiba.service.HttpRetryRulesService;
import cn.com.duiba.service.ThreadPoolService;
import cn.com.duiba.thirdparty.dto.HttpRequestMessageDto;
import cn.com.duiba.thirdparty.dto.HttpResponseMessageDto;
import cn.com.duiba.tool.AssembleTool;
import cn.com.duiba.tool.CaiNiaoTool;
import cn.com.duiba.tool.HttpRequestLog;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang3.StringEscapeUtils;
import org.apache.http.Header;
import org.apache.http.HttpResponse;
import org.apache.http.client.entity.GzipDecompressingEntity;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpRequestBase;
import org.apache.http.concurrent.FutureCallback;
import org.apache.http.entity.StringEntity;
import org.apache.http.util.EntityUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Map;

/**
 * 订单状态变更同步第三方
 */
@Service
public class OrderStatusPushHttp {

    private static Logger logger = LoggerFactory.getLogger(OrderStatusPushHttp.class);

    @Autowired
    private HttpRetryRulesService httpRetryRulesService;
    @Autowired
    private AppDAO appDAO;
    @Autowired
    private HttpMessageDAO httpMessageDAO;
    @Autowired
    private ThreadPoolService threadPoolService;
    @Autowired
    private NotifyHttpClientPool notifyHttpClientPool;
    @Autowired
    private OrderStatusPushConfig orderStatusPushConfig;

    /**
     * 提交订单状态变更同步请求
     *
     * @param message
     */
    public void asyncSubmit(final String message) {
        final HttpRequestMessageDto dto = JSONObject.parseObject(message, HttpRequestMessageDto.class);
        logger.info("订单推送数据:{}", JSON.toJSONString(dto));
        AppDO app = appDAO.findAppSimple(dto.getAppId());
        if (app == null) {
            logger.warn("appId:{} is empty", dto.getAppId());
            return;
        }

        HttpMessageDO hmd = new HttpMessageDO();
        hmd.setAppId(dto.getAppId());
        hmd.setBizType(dto.getBizType());
        hmd.setBizParams(JSONObject.toJSONString(dto.getHttpParams()));
        hmd.setNumber(0);
        hmd.setOffset(httpRetryRulesService.getNextSecond(hmd));
        httpMessageDAO.insert(hmd);

        asyncSubmit(hmd, dto, app);
    }

    /**
     * 提交HTTP请求
     *
     * @param db
     * @param msg
     * @param app
     */
    public void asyncSubmit(final HttpMessageDO db, final HttpRequestMessageDto msg, AppDO app) {
        if (app == null) {
            return;
        }
        OrderStatusPushConfig.OrderStatusPushBean orderStatusPushBean = orderStatusPushConfig.getConfigMap().get(app.getId());
        if (orderStatusPushBean == null) {
            logger.info("appId:{} orderStatusPushBean is empty", app.getId());
        }
        String url = orderStatusPushBean.getPushUrl();
        Map<String, String> map = msg.getHttpParams();
        if (MapUtils.isEmpty(map)) {
            return;
        }
        map.put("appKey", app.getAppKey());
        map.put("appSecret", appDAO.getAppSecret(app));
        String sign = SignTool.sign(map);
        map.put("sign", sign);
        map.remove("appSecret");
        HttpPost httpPost = new HttpPost(url.trim());
        String paramsJsonStr = JSONObject.toJSONString(map);
        logger.info("订单推送 请求url :{} 请求入参:{}",url, paramsJsonStr);
        StringEntity body = new StringEntity(paramsJsonStr, "UTF-8");
        httpPost.setEntity(body);
        httpPost.setHeader("Content-Type", "application/json; charset=UTF-8");
        HttpRequestLog.logUrl("[action orderStatusPush] [tag get request] [url " + url  + "] [bizId "+map.get("orderNum")+ "][body " + paramsJsonStr + "]");

        submitReq(msg, httpPost, db, url);
    }


    private void submitReq(HttpRequestMessageDto msg, HttpRequestBase http, HttpMessageDO db, String url) {

        notifyHttpClientPool.submit(msg.getAppId(), http, new FutureCallback<HttpResponse>() {

            @Override
            public void completed(HttpResponse response) {
                HttpResponseMessageDto resp = new HttpResponseMessageDto();
                try {
                    resp.setCallbackType(HttpResponseMessageDto.CALLBACK_TYPE_COMPLETED);
                    resp.setHttpUrl(url);
                    String body = EntityUtils.toString(response.getEntity());
                    if (StringUtils.isNotEmpty(body)) {
                        String cont = body.toLowerCase();
                        if (cont.contains("ok")) {
                            resp.setSuccess(true);
                        }
                    }
                    resp.setBody(HttpRequestLog.subBody(body));
                    resp.setBizId(msg.getBizId());
                    resp.setBizType(msg.getBizType());
                } catch (Exception e) {
                    resp.setSuccess(false);
                    resp.setErrorMessage("请求失败:completed:" + e.getMessage());
                    logger.error("completed param: {}", getCrecordParam(msg), e);
                } finally {
                    httpRequestComleted(db, msg, resp);
                }
            }

            @Override
            public void failed(Exception ex) {
                logger.warn("orderStatusPush failed param: {}, errMsg: {}", getCrecordParam(msg), getErrorMsg(ex), ex);

                HttpResponseMessageDto resp = new HttpResponseMessageDto();
                resp.setCallbackType(HttpResponseMessageDto.CALLBACK_TYPE_FAILED);
                resp.setHttpUrl(url);
                resp.setBizId(msg.getBizId());
                resp.setBizType(msg.getBizType());
                resp.setSuccess(false);
                resp.setErrorMessage("请求失败:failed:" + ex.getMessage());
                httpRequestComleted(db, msg, resp);
            }

            @Override
            public void cancelled() {
                logger.warn("orderStatusPush failed param:" + getCrecordParam(msg));
                HttpResponseMessageDto resp = new HttpResponseMessageDto();
                resp.setCallbackType(HttpResponseMessageDto.CALLBACK_TYPE_CANCELLED);
                resp.setHttpUrl(url);
                resp.setBizId(msg.getBizId());
                resp.setBizType(msg.getBizType());
                resp.setSuccess(false);
                resp.setErrorMessage("请求失败:cancelled");
                httpRequestComleted(db, msg, resp);
            }

        });
    }

    private String getErrorMsg(Exception ex) {
        String errMsg = ex.getMessage();
        if (ex.getCause() != null) {
            errMsg = ex.getCause().getMessage();
        }
        return errMsg;
    }

    private String getCrecordParam(HttpRequestMessageDto msg) {
        return msg.getHttpParams() != null ? JSONObject.toJSONString(msg.getHttpParams()) : "null";
    }


    /**
     * httpRequestComleted
     *
     * @param db
     * @param resp
     */
    private void httpRequestComleted(final HttpMessageDO db, HttpRequestMessageDto requestMessageDto, final HttpResponseMessageDto resp) {
        HttpRequestLog.logUrl("[action orderStatusPush Response][callback " + resp.getCallbackType() + "] [bizId " + requestMessageDto.getHttpParams().get("orderNum") + "] [body " + resp.getBody() + "]");
        logger.info("订单推送响应:{}", resp.getBody());
        threadPoolService.submit(new Runnable() {
            @Override
            public void run() {
                try {
                    if (!HttpResponseMessageDto.CALLBACK_TYPE_COMPLETED.equals(resp.getCallbackType()) || !"ok".equalsIgnoreCase(resp.getBody())) {
                        if (db.getNumber() >= httpRetryRulesService.getRetryNumber(db)) {
                            httpMessageDAO.delete(db.getId());
                            return;
                        }
                        httpMessageDAO.updateNextTime(db.getId(), httpRetryRulesService.getNextSecond(db));
                        return;
                    }
                    httpMessageDAO.delete(db.getId());
                } catch (Exception e) {
                    logger.error("httpRequestComleted", e);
                }
            }
        });

    }

}

==> thirdparty-service-biz-1.0.56-20220608.112006-1-sources.jar: cn/com/duiba/orderstatus/OrderStatusPushHttp.java <==
package cn.com.duiba.orderstatus;

import cn.com.duiba.biz.credits.strategy.ApiStrategy;
import cn.com.duiba.biz.credits.strategy.ApiStrategyRouter;
import cn.com.duiba.config.OrderStatusPushConfig;
import cn.com.duiba.credits.sdk.SignTool;
import cn.com.duiba.dao.AppDAO;
import cn.com.duiba.dao.HttpMessageDAO;
import cn.com.duiba.domain.AppDO;
import cn.com.duiba.domain.HttpMessageDO;
import cn.com.duiba.notifycenter.service.NotifyHttpClientPool;
import cn.com.duiba.service.HttpRetryRulesService;
import cn.com.duiba.service.ThreadPoolService;
import cn.com.duiba.thirdparty.dto.HttpRequestMessageDto;
import cn.com.duiba.thirdparty.dto.HttpResponseMessageDto;
import cn.com.duiba.tool.HttpRequestLog;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.http.HttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpRequestBase;
import org.apache.http.concurrent.FutureCallback;
import org.apache.http.entity.StringEntity;
import org.apache.http.util.EntityUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Map;
import java.util.Objects;

/**
 * 订单状态变更同步第三方
 */
@Service
public class OrderStatusPushHttp {

    private static Logger logger = LoggerFactory.getLogger(OrderStatusPushHttp.class);

    @Autowired
    private HttpRetryRulesService httpRetryRulesService;
    @Autowired
    private AppDAO appDAO;
    @Autowired
    private HttpMessageDAO httpMessageDAO;
    @Autowired
    private ThreadPoolService threadPoolService;
    @Autowired
    private NotifyHttpClientPool notifyHttpClientPool;
    @Autowired
    private OrderStatusPushConfig orderStatusPushConfig;

    /**
     * 提交订单状态变更同步请求
     *
     * @param message
     */
    public void asyncSubmit(final String message) {
        final HttpRequestMessageDto dto = JSONObject.parseObject(message, HttpRequestMessageDto.class);
        logger.info("订单推送数据:{}", JSON.toJSONString(dto));
        AppDO app = appDAO.findAppSimple(dto.getAppId());
        if (app == null) {
            logger.warn("appId:{} is empty", dto.getAppId());
            return;
        }

        HttpMessageDO hmd = new HttpMessageDO();
        hmd.setAppId(dto.getAppId());
        hmd.setBizType(dto.getBizType());
        hmd.setBizParams(JSONObject.toJSONString(dto.getHttpParams()));
        hmd.setNumber(0);
        hmd.setOffset(httpRetryRulesService.getNextSecond(hmd));
        httpMessageDAO.insert(hmd);

        asyncSubmit(hmd, dto, app);
    }

    /**
     * 提交HTTP请求
     *
     * @param db
     * @param msg
     * @param app
     */
    public void asyncSubmit(final HttpMessageDO db, final HttpRequestMessageDto msg, AppDO app) {
        if (app == null) {
            return;
        }

        ApiStrategy apiStrategy = ApiStrategyRouter.route(app.getId());
        if (apiStrategy != null) {
            HttpRequestBase httpRequestBase = apiStrategy.getOrderStatusPushHttp(db, msg, app);
            if (Objects.nonNull(httpRequestBase)){
                Map<String, String> httpParams = msg.getHttpParams();
                String url = httpRequestBase.getURI().toString();
                HttpRequestLog.logUrl("[action orderStatusPush] [tag get request] [url " + url  + "] [bizId "+httpParams.get("orderNum")+ "][body " + httpRequestBase.getParams() + "]");
                submitReq(msg, httpRequestBase, db, url);
                return;
            }
        }

        OrderStatusPushConfig.OrderStatusPushBean orderStatusPushBean = orderStatusPushConfig.getConfigMap().get(app.getId());
        if (orderStatusPushBean == null) {
            logger.info("appId:{} orderStatusPushBean is empty", app.getId());
            return;
        }
        String url = orderStatusPushBean.getPushUrl();
        Map<String, String> map = msg.getHttpParams();
        if (MapUtils.isEmpty(map)) {
            return;
        }
        map.put("appKey", app.getAppKey());
        map.put("appSecret", appDAO.getAppSecret(app));
        String sign = SignTool.sign(map);
        map.put("sign", sign);
        map.remove("appSecret");
        HttpPost httpPost = new HttpPost(url.trim());
        String paramsJsonStr = JSONObject.toJSONString(map);
        logger.info("订单推送 请求url :{} 请求入参:{}",url, paramsJsonStr);
        StringEntity body = new StringEntity(paramsJsonStr, "UTF-8");
        httpPost.setEntity(body);
        httpPost.setHeader("Content-Type", "application/json; charset=UTF-8");
        HttpRequestLog.logUrl("[action orderStatusPush] [tag get request] [url " + url  + "] [bizId "+map.get("orderNum")+ "][body " + paramsJsonStr + "]");

        submitReq(msg, httpPost, db, url);
    }


    private void submitReq(HttpRequestMessageDto msg, HttpRequestBase http, HttpMessageDO db, String url) {

        notifyHttpClientPool.submit(msg.getAppId(), http, new FutureCallback<HttpResponse>() {

            @Override
            public void completed(HttpResponse response) {
                HttpResponseMessageDto resp = new HttpResponseMessageDto();
                try {
                    resp.setCallbackType(HttpResponseMessageDto.CALLBACK_TYPE_COMPLETED);
                    resp.setHttpUrl(url);
                    String body = EntityUtils.toString(response.getEntity());
                    if (StringUtils.isNotEmpty(body)) {
                        String cont = body.toLowerCase();
                        if (cont.contains("ok")) {
                            resp.setSuccess(true);
                        }
                    }
                    resp.setBody(HttpRequestLog.subBody(body));
                    resp.setBizId(msg.getBizId());
                    resp.setBizType(msg.getBizType());
                } catch (Exception e) {
                    resp.setSuccess(false);
                    resp.setErrorMessage("请求失败:completed:" + e.getMessage());
                    logger.error("completed param: {}", getCrecordParam(msg), e);
                } finally {
                    httpRequestComleted(db, msg, resp);
                }
            }

            @Override
            public void failed(Exception ex) {
                logger.warn("orderStatusPush failed param: {}, errMsg: {}", getCrecordParam(msg), getErrorMsg(ex), ex);

                HttpResponseMessageDto resp = new HttpResponseMessageDto();
                resp.setCallbackType(HttpResponseMessageDto.CALLBACK_TYPE_FAILED);
                resp.setHttpUrl(url);
                resp.setBizId(msg.getBizId());
                resp.setBizType(msg.getBizType());
                resp.setSuccess(false);
                resp.setErrorMessage("请求失败:failed:" + ex.getMessage());
                httpRequestComleted(db, msg, resp);
            }

            @Override
            public void cancelled() {
                logger.warn("orderStatusPush failed param:" + getCrecordParam(msg));
                HttpResponseMessageDto resp = new HttpResponseMessageDto();
                resp.setCallbackType(HttpResponseMessageDto.CALLBACK_TYPE_CANCELLED);
                resp.setHttpUrl(url);
                resp.setBizId(msg.getBizId());
                resp.setBizType(msg.getBizType());
                resp.setSuccess(false);
                resp.setErrorMessage("请求失败:cancelled");
                httpRequestComleted(db, msg, resp);
            }

        });
    }

    private String getErrorMsg(Exception ex) {
        String errMsg = ex.getMessage();
        if (ex.getCause() != null) {
            errMsg = ex.getCause().getMessage();
        }
        return errMsg;
    }

    private String getCrecordParam(HttpRequestMessageDto msg) {
        return msg.getHttpParams() != null ? JSONObject.toJSONString(msg.getHttpParams()) : "null";
    }


    /**
     * httpRequestComleted
     *
     * @param db
     * @param resp
     */
    private void httpRequestComleted(final HttpMessageDO db, HttpRequestMessageDto requestMessageDto, final HttpResponseMessageDto resp) {
        HttpRequestLog.logUrl("[action orderStatusPush Response][callback " + resp.getCallbackType() + "] [bizId " + requestMessageDto.getHttpParams().get("orderNum") + "] [body " + resp.getBody() + "]");
        logger.info("订单推送响应:{}", resp.getBody());
        threadPoolService.submit(new Runnable() {
            @Override
            public void run() {
                try {
                    if (!HttpResponseMessageDto.CALLBACK_TYPE_COMPLETED.equals(resp.getCallbackType()) || !"ok".equalsIgnoreCase(resp.getBody())) {
                        if (db.getNumber() >= httpRetryRulesService.getRetryNumber(db)) {
                            httpMessageDAO.delete(db.getId());
                            return;
                        }
                        httpMessageDAO.updateNextTime(db.getId(), httpRetryRulesService.getNextSecond(db));
                        return;
                    }
                    httpMessageDAO.delete(db.getId());
                } catch (Exception e) {
                    logger.error("httpRequestComleted", e);
                }
            }
        });

    }

}
